from PyObjCTools.TestSupport import TestCase, min_os_level

import GameController


class TestGCKeyboard(TestCase):
    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(GameController.GCKeyboardDidConnectNotification, str)
        self.assertIsInstance(GameController.GCKeyboardDidDisconnectNotification, str)



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import objc
import GameController  # noqa: F401


class TestGCDevice(TestCase):
    @min_sdk_level("11.0")
    def test_protocols11_0(self):
        objc.protocolNamed("GCDevice")



from PyObjCTools.TestSupport import TestCase, min_os_level
import GameController


class TestGCKeyCodes(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(GameController.GCKeyCode, int)

    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(GameController.GCKeyCodeKeyA, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyB, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyC, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyD, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyE, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyF, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyG, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyH, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyI, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyJ, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyK, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyL, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyM, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyN, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyO, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyP, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyQ, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyR, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyS, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyT, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyU, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyV, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyW, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyX, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyY, int)
        self.assertIsInstance(GameController.GCKeyCodeKeyZ, int)
        self.assertIsInstance(GameController.GCKeyCodeOne, int)
        self.assertIsInstance(GameController.GCKeyCodeTwo, int)
        self.assertIsInstance(GameController.GCKeyCodeThree, int)
        self.assertIsInstance(GameController.GCKeyCodeFour, int)
        self.assertIsInstance(GameController.GCKeyCodeFive, int)
        self.assertIsInstance(GameController.GCKeyCodeSix, int)
        self.assertIsInstance(GameController.GCKeyCodeSeven, int)
        self.assertIsInstance(GameController.GCKeyCodeEight, int)
        self.assertIsInstance(GameController.GCKeyCodeNine, int)
        self.assertIsInstance(GameController.GCKeyCodeZero, int)
        self.assertIsInstance(GameController.GCKeyCodeReturnOrEnter, int)
        self.assertIsInstance(GameController.GCKeyCodeEscape, int)
        self.assertIsInstance(GameController.GCKeyCodeDeleteOrBackspace, int)
        self.assertIsInstance(GameController.GCKeyCodeTab, int)
        self.assertIsInstance(GameController.GCKeyCodeSpacebar, int)
        self.assertIsInstance(GameController.GCKeyCodeHyphen, int)
        self.assertIsInstance(GameController.GCKeyCodeEqualSign, int)
        self.assertIsInstance(GameController.GCKeyCodeOpenBracket, int)
        self.assertIsInstance(GameController.GCKeyCodeCloseBracket, int)
        self.assertIsInstance(GameController.GCKeyCodeBackslash, int)
        self.assertIsInstance(GameController.GCKeyCodeNonUSPound, int)
        self.assertIsInstance(GameController.GCKeyCodeSemicolon, int)
        self.assertIsInstance(GameController.GCKeyCodeQuote, int)
        self.assertIsInstance(GameController.GCKeyCodeGraveAccentAndTilde, int)
        self.assertIsInstance(GameController.GCKeyCodeComma, int)
        self.assertIsInstance(GameController.GCKeyCodePeriod, int)
        self.assertIsInstance(GameController.GCKeyCodeSlash, int)
        self.assertIsInstance(GameController.GCKeyCodeCapsLock, int)

        self.assertIsInstance(GameController.GCKeyCodeF1, int)
        self.assertIsInstance(GameController.GCKeyCodeF2, int)
        self.assertIsInstance(GameController.GCKeyCodeF3, int)
        self.assertIsInstance(GameController.GCKeyCodeF4, int)
        self.assertIsInstance(GameController.GCKeyCodeF5, int)
        self.assertIsInstance(GameController.GCKeyCodeF6, int)
        self.assertIsInstance(GameController.GCKeyCodeF7, int)
        self.assertIsInstance(GameController.GCKeyCodeF8, int)
        self.assertIsInstance(GameController.GCKeyCodeF9, int)
        self.assertIsInstance(GameController.GCKeyCodeF10, int)
        self.assertIsInstance(GameController.GCKeyCodeF11, int)
        self.assertIsInstance(GameController.GCKeyCodeF12, int)

        self.assertIsInstance(GameController.GCKeyCodePrintScreen, int)
        self.assertIsInstance(GameController.GCKeyCodeScrollLock, int)
        self.assertIsInstance(GameController.GCKeyCodePause, int)
        self.assertIsInstance(GameController.GCKeyCodeInsert, int)
        self.assertIsInstance(GameController.GCKeyCodeHome, int)
        self.assertIsInstance(GameController.GCKeyCodePageUp, int)
        self.assertIsInstance(GameController.GCKeyCodeDeleteForward, int)
        self.assertIsInstance(GameController.GCKeyCodeEnd, int)
        self.assertIsInstance(GameController.GCKeyCodePageDown, int)
        self.assertIsInstance(GameController.GCKeyCodeRightArrow, int)
        self.assertIsInstance(GameController.GCKeyCodeLeftArrow, int)
        self.assertIsInstance(GameController.GCKeyCodeDownArrow, int)
        self.assertIsInstance(GameController.GCKeyCodeUpArrow, int)

        self.assertIsInstance(GameController.GCKeyCodeKeypadNumLock, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadSlash, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadAsterisk, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadHyphen, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadPlus, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadEnter, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad1, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad2, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad3, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad4, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad5, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad6, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad7, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad8, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad9, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypad0, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadPeriod, int)
        self.assertIsInstance(GameController.GCKeyCodeKeypadEqualSign, int)
        self.assertIsInstance(GameController.GCKeyCodeNonUSBackslash, int)

        self.assertIsInstance(GameController.GCKeyCodeApplication, int)
        self.assertIsInstance(GameController.GCKeyCodePower, int)

        self.assertIsInstance(GameController.GCKeyCodeInternational1, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational2, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational3, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational4, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational5, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational6, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational7, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational8, int)
        self.assertIsInstance(GameController.GCKeyCodeInternational9, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG1, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG2, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG3, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG4, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG5, int)

        self.assertIsInstance(GameController.GCKeyCodeLANG6, int)
        self.assertIsInstance(GameController.GCKeyCodeLANG7, int)
        self.assertIsInstance(GameController.GCKeyCodeLANG8, int)
        self.assertIsInstance(GameController.GCKeyCodeLANG9, int)

        self.assertIsInstance(GameController.GCKeyCodeLeftControl, int)
        self.assertIsInstance(GameController.GCKeyCodeLeftShift, int)
        self.assertIsInstance(GameController.GCKeyCodeLeftAlt, int)
        self.assertIsInstance(GameController.GCKeyCodeLeftGUI, int)
        self.assertIsInstance(GameController.GCKeyCodeRightControl, int)
        self.assertIsInstance(GameController.GCKeyCodeRightShift, int)
        self.assertIsInstance(GameController.GCKeyCodeRightAlt, int)
        self.assertIsInstance(GameController.GCKeyCodeRightGUI, int)



from PyObjCTools.TestSupport import (
    TestCase,
    min_os_level,
    os_release,
    expectedFailureIf,
)
import objc
import GameController


class TestGCMicroGamepad(TestCase):
    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertIsInstance(GameController.GCInputMicroGamepadDpad, str)
        self.assertIsInstance(GameController.GCInputMicroGamepadButtonA, str)
        self.assertIsInstance(GameController.GCInputMicroGamepadButtonX, str)
        self.assertIsInstance(GameController.GCInputMicroGamepadButtonMenu, str)

    @expectedFailureIf(os_release() == "10.11")
    @min_os_level("10.11")
    def testClasses(self):
        self.assertIsInstance(GameController.GCMicroGamepad, objc.objc_class)

    @expectedFailureIf(os_release() == "10.11")
    @min_os_level("10.11")
    def testMethods(self):
        self.assertResultIsBlock(
            GameController.GCMicroGamepad.valueChangedHandler, b"v@@"
        )
        self.assertArgIsBlock(
            GameController.GCMicroGamepad.setValueChangedHandler_, 0, b"v@@"
        )

        self.assertResultIsBOOL(GameController.GCMicroGamepad.reportsAbsoluteDpadValues)
        self.assertArgIsBOOL(
            GameController.GCMicroGamepad.setReportsAbsoluteDpadValues_, 0
        )

        self.assertResultIsBOOL(GameController.GCMicroGamepad.allowsRotation)
        self.assertArgIsBOOL(GameController.GCMicroGamepad.setAllowsRotation_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import GameController


class TestGCControllerAxisInput(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(GameController.GCControllerAxisInput, objc.objc_class)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertResultIsBlock(
            GameController.GCControllerAxisInput.valueChangedHandler, b"v@f"
        )
        self.assertArgIsBlock(
            GameController.GCControllerAxisInput.setValueChangedHandler_, 0, b"v@f"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import GameController


class TestGCPhysicalInputProfile(TestCase):
    @min_os_level("12.0")
    def testMethods(self):
        self.assertResultIsBOOL(
            GameController.GCPhysicalInputProfile.hasRemappedElements
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import GameController


class TestGCKeyNames(TestCase):
    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(GameController.GCKeyA, str)
        self.assertIsInstance(GameController.GCKeyB, str)
        self.assertIsInstance(GameController.GCKeyC, str)
        self.assertIsInstance(GameController.GCKeyD, str)
        self.assertIsInstance(GameController.GCKeyE, str)
        self.assertIsInstance(GameController.GCKeyF, str)
        self.assertIsInstance(GameController.GCKeyG, str)
        self.assertIsInstance(GameController.GCKeyH, str)
        self.assertIsInstance(GameController.GCKeyI, str)
        self.assertIsInstance(GameController.GCKeyJ, str)
        self.assertIsInstance(GameController.GCKeyK, str)
        self.assertIsInstance(GameController.GCKeyL, str)
        self.assertIsInstance(GameController.GCKeyM, str)
        self.assertIsInstance(GameController.GCKeyN, str)
        self.assertIsInstance(GameController.GCKeyO, str)
        self.assertIsInstance(GameController.GCKeyP, str)
        self.assertIsInstance(GameController.GCKeyQ, str)
        self.assertIsInstance(GameController.GCKeyR, str)
        self.assertIsInstance(GameController.GCKeyS, str)
        self.assertIsInstance(GameController.GCKeyT, str)
        self.assertIsInstance(GameController.GCKeyU, str)
        self.assertIsInstance(GameController.GCKeyV, str)
        self.assertIsInstance(GameController.GCKeyW, str)
        self.assertIsInstance(GameController.GCKeyX, str)
        self.assertIsInstance(GameController.GCKeyY, str)
        self.assertIsInstance(GameController.GCKeyZ, str)
        self.assertIsInstance(GameController.GCKeyOne, str)
        self.assertIsInstance(GameController.GCKeyTwo, str)
        self.assertIsInstance(GameController.GCKeyThree, str)
        self.assertIsInstance(GameController.GCKeyFour, str)
        self.assertIsInstance(GameController.GCKeyFive, str)
        self.assertIsInstance(GameController.GCKeySix, str)
        self.assertIsInstance(GameController.GCKeySeven, str)
        self.assertIsInstance(GameController.GCKeyEight, str)
        self.assertIsInstance(GameController.GCKeyNine, str)
        self.assertIsInstance(GameController.GCKeyZero, str)
        self.assertIsInstance(GameController.GCKeyReturnOrEnter, str)
        self.assertIsInstance(GameController.GCKeyEscape, str)
        self.assertIsInstance(GameController.GCKeyDeleteOrBackspace, str)
        self.assertIsInstance(GameController.GCKeyTab, str)
        self.assertIsInstance(GameController.GCKeySpacebar, str)
        self.assertIsInstance(GameController.GCKeyHyphen, str)
        self.assertIsInstance(GameController.GCKeyEqualSign, str)
        self.assertIsInstance(GameController.GCKeyOpenBracket, str)
        self.assertIsInstance(GameController.GCKeyCloseBracket, str)
        self.assertIsInstance(GameController.GCKeyBackslash, str)
        self.assertIsInstance(GameController.GCKeyNonUSPound, str)
        self.assertIsInstance(GameController.GCKeySemicolon, str)
        self.assertIsInstance(GameController.GCKeyQuote, str)
        self.assertIsInstance(GameController.GCKeyGraveAccentAndTilde, str)
        self.assertIsInstance(GameController.GCKeyComma, str)
        self.assertIsInstance(GameController.GCKeyPeriod, str)
        self.assertIsInstance(GameController.GCKeySlash, str)
        self.assertIsInstance(GameController.GCKeyCapsLock, str)

        self.assertIsInstance(GameController.GCKeyF1, str)
        self.assertIsInstance(GameController.GCKeyF2, str)
        self.assertIsInstance(GameController.GCKeyF3, str)
        self.assertIsInstance(GameController.GCKeyF4, str)
        self.assertIsInstance(GameController.GCKeyF5, str)
        self.assertIsInstance(GameController.GCKeyF6, str)
        self.assertIsInstance(GameController.GCKeyF7, str)
        self.assertIsInstance(GameController.GCKeyF8, str)
        self.assertIsInstance(GameController.GCKeyF9, str)
        self.assertIsInstance(GameController.GCKeyF10, str)
        self.assertIsInstance(GameController.GCKeyF11, str)
        self.assertIsInstance(GameController.GCKeyF12, str)
        self.assertIsInstance(GameController.GCKeyPrintScreen, str)
        self.assertIsInstance(GameController.GCKeyScrollLock, str)
        self.assertIsInstance(GameController.GCKeyPause, str)
        self.assertIsInstance(GameController.GCKeyInsert, str)
        self.assertIsInstance(GameController.GCKeyHome, str)
        self.assertIsInstance(GameController.GCKeyPageUp, str)
        self.assertIsInstance(GameController.GCKeyDeleteForward, str)
        self.assertIsInstance(GameController.GCKeyEnd, str)
        self.assertIsInstance(GameController.GCKeyPageDown, str)
        self.assertIsInstance(GameController.GCKeyRightArrow, str)
        self.assertIsInstance(GameController.GCKeyLeftArrow, str)
        self.assertIsInstance(GameController.GCKeyDownArrow, str)
        self.assertIsInstance(GameController.GCKeyUpArrow, str)

        self.assertIsInstance(GameController.GCKeyKeypadNumLock, str)
        self.assertIsInstance(GameController.GCKeyKeypadSlash, str)
        self.assertIsInstance(GameController.GCKeyKeypadAsterisk, str)
        self.assertIsInstance(GameController.GCKeyKeypadHyphen, str)
        self.assertIsInstance(GameController.GCKeyKeypadPlus, str)
        self.assertIsInstance(GameController.GCKeyKeypadEnter, str)
        self.assertIsInstance(GameController.GCKeyKeypad1, str)
        self.assertIsInstance(GameController.GCKeyKeypad2, str)
        self.assertIsInstance(GameController.GCKeyKeypad3, str)
        self.assertIsInstance(GameController.GCKeyKeypad4, str)
        self.assertIsInstance(GameController.GCKeyKeypad5, str)
        self.assertIsInstance(GameController.GCKeyKeypad6, str)
        self.assertIsInstance(GameController.GCKeyKeypad7, str)
        self.assertIsInstance(GameController.GCKeyKeypad8, str)
        self.assertIsInstance(GameController.GCKeyKeypad9, str)
        self.assertIsInstance(GameController.GCKeyKeypad0, str)
        self.assertIsInstance(GameController.GCKeyKeypadPeriod, str)
        self.assertIsInstance(GameController.GCKeyKeypadEqualSign, str)
        self.assertIsInstance(GameController.GCKeyNonUSBackslash, str)

        self.assertIsInstance(GameController.GCKeyApplication, str)
        self.assertIsInstance(GameController.GCKeyPower, str)

        self.assertIsInstance(GameController.GCKeyInternational1, str)
        self.assertIsInstance(GameController.GCKeyInternational2, str)
        self.assertIsInstance(GameController.GCKeyInternational3, str)
        self.assertIsInstance(GameController.GCKeyInternational4, str)
        self.assertIsInstance(GameController.GCKeyInternational5, str)
        self.assertIsInstance(GameController.GCKeyInternational6, str)
        self.assertIsInstance(GameController.GCKeyInternational7, str)
        self.assertIsInstance(GameController.GCKeyInternational8, str)
        self.assertIsInstance(GameController.GCKeyInternational9, str)

        self.assertIsInstance(GameController.GCKeyLANG1, str)

        self.assertIsInstance(GameController.GCKeyLANG2, str)

        self.assertIsInstance(GameController.GCKeyLANG3, str)

        self.assertIsInstance(GameController.GCKeyLANG4, str)

        self.assertIsInstance(GameController.GCKeyLANG5, str)

        self.assertIsInstance(GameController.GCKeyLANG6, str)
        self.assertIsInstance(GameController.GCKeyLANG7, str)
        self.assertIsInstance(GameController.GCKeyLANG8, str)
        self.assertIsInstance(GameController.GCKeyLANG9, str)

        self.assertIsInstance(GameController.GCKeyLeftControl, str)
        self.assertIsInstance(GameController.GCKeyLeftShift, str)
        self.assertIsInstance(GameController.GCKeyLeftAlt, str)
        self.assertIsInstance(GameController.GCKeyLeftGUI, str)
        self.assertIsInstance(GameController.GCKeyRightControl, str)
        self.assertIsInstance(GameController.GCKeyRightShift, str)
        self.assertIsInstance(GameController.GCKeyRightAlt, str)
        self.assertIsInstance(GameController.GCKeyRightGUI, str)

    @min_os_level("12.0")
    def test_constants12_0(self):
        self.assertIsInstance(GameController.GCKeyF13, str)
        self.assertIsInstance(GameController.GCKeyF14, str)
        self.assertIsInstance(GameController.GCKeyF15, str)
        self.assertIsInstance(GameController.GCKeyF16, str)
        self.assertIsInstance(GameController.GCKeyF17, str)
        self.assertIsInstance(GameController.GCKeyF18, str)
        self.assertIsInstance(GameController.GCKeyF19, str)
        self.assertIsInstance(GameController.GCKeyF20, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import GameController


class TestGCControllerElement(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(GameController.GCSystemGestureState)

    def test_constants(self):
        self.assertEqual(GameController.GCSystemGestureStateEnabled, 0)
        self.assertEqual(GameController.GCSystemGestureStateAlwaysReceive, 1)
        self.assertEqual(GameController.GCSystemGestureStateDisabled, 2)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(GameController.GCControllerElement, objc.objc_class)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertResultIsBOOL(GameController.GCControllerElement.isAnalog)

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertResultIsBOOL(
            GameController.GCControllerElement.isBoundToSystemGesture
        )



from PyObjCTools.TestSupport import TestCase
import GameController


class TestGCDeviceBattery(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(GameController.GCDeviceBatteryState)

    def test_constants(self):
        self.assertEqual(GameController.GCDeviceBatteryStateUnknown, -1)
        self.assertEqual(GameController.GCDeviceBatteryStateDischarging, 0)
        self.assertEqual(GameController.GCDeviceBatteryStateCharging, 1)
        self.assertEqual(GameController.GCDeviceBatteryStateFull, 2)



from PyObjCTools.TestSupport import TestCase, min_os_level
import GameController


class TestGCEventViewController(TestCase):
    @min_os_level("10.15")
    def test_methods10_15(self):
        self.assertResultIsBOOL(
            GameController.GCEventViewController.controllerUserInteractionEnabled
        )
        self.assertArgIsBOOL(
            GameController.GCEventViewController.setControllerUserInteractionEnabled_, 0
        )



from PyObjCTools.TestSupport import (
    TestCase,
    min_os_level,
    os_release,
    expectedFailureIf,
)
import objc
import GameController


class TestGCController(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(GameController.GCControllerPlayerIndex)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(GameController.GCController, objc.objc_class)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertResultIsBlock(
            GameController.GCController.controllerPausedHandler, b"v@"
        )
        self.assertArgIsBlock(
            GameController.GCController.setControllerPausedHandler_, 0, b"v@"
        )

        self.assertResultIsBOOL(GameController.GCController.isAttachedToDevice)
        # self.assertArgIsBOOL(GameController.GCController.setAttachedToDevice_, 0)

        self.assertArgIsBlock(
            GameController.GCController.startWirelessControllerDiscoveryWithCompletionHandler_,
            0,
            b"v",
        )

    @expectedFailureIf(os_release() == "10.11")
    @min_os_level("10.11")
    def testMethods10_11(self):
        self.assertResultIsBOOL(
            GameController.GCEventViewController.controllerUserInteractionEnabled
        )
        self.assertArgIsBOOL(
            GameController.GCEventViewController.setControllerUserInteractionEnabled_, 0
        )

    @min_os_level("10.15")
    def testMethods10_15(self):
        self.assertResultIsBOOL(GameController.GCController.isSnapshot)

    @min_os_level("11.0")
    def testMethods11_0(self):
        self.assertResultIsBOOL(GameController.GCController.supportsHIDDevice_)

    @min_os_level("11.3")
    def testMethods11_3(self):
        self.assertResultIsBOOL(
            GameController.GCController.shouldMonitorBackgroundEvents
        )
        self.assertArgIsBOOL(
            GameController.GCController.setShouldMonitorBackgroundEvents_, 0
        )

    @min_os_level("10.9")
    def test_constants(self):
        self.assertIsInstance(GameController.GCControllerDidConnectNotification, str)
        self.assertIsInstance(GameController.GCControllerDidDisconnectNotification, str)
        self.assertEqual(GameController.GCControllerPlayerIndexUnset, -1)

    @min_os_level("11.0")
    def test_constants11_0(self):
        self.assertIsInstance(
            GameController.GCControllerDidBecomeCurrentNotification, str
        )
        self.assertIsInstance(
            GameController.GCControllerDidStopBeingCurrentNotification, str
        )



"""
Python mapping for the GameController framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Cocoa
import objc
from GameController import _metadata
from GameController import _GameController

sys.modules["GameController"] = mod = objc.ObjCLazyModule(
    "GameController",
    "com.apple.GameController",
    objc.pathForFramework("/System/Library/Frameworks/GameController.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_GameController, Cocoa),
)


del sys.modules["GameController._metadata"]



from PyObjCTools.TestSupport import (
    TestCase,
    min_os_level,
)
import GameController


class TestGCProductCategories(TestCase):
    @min_os_level("12.0")
    def test_constants(self):
        self.assertIsInstance(GameController.GCProductCategoryDualSense, str)
        self.assertIsInstance(GameController.GCProductCategoryDualShock4, str)
        self.assertIsInstance(GameController.GCProductCategoryMFi, str)
        self.assertIsInstance(GameController.GCProductCategoryXboxOne, str)

        self.assertIsInstance(GameController.GCProductCategorySiriRemote1stGen, str)

        self.assertIsInstance(GameController.GCProductCategorySiriRemote2ndGen, str)

        self.assertIsInstance(GameController.GCProductCategoryControlCenterRemote, str)

        self.assertIsInstance(
            GameController.GCProductCategoryUniversalElectronicsRemote, str
        )

        self.assertIsInstance(GameController.GCProductCategoryCoalescedRemote, str)

        self.assertIsInstance(GameController.GCProductCategoryMouse, str)
        self.assertIsInstance(GameController.GCProductCategoryKeyboard, str)
